==> zio-aws-route53recoverycontrolconfig_3-5.17.127.1-sources.jar: zio/aws/route53recoverycontrolconfig/model/DescribeClusterRequest.scala <==
package zio.aws.route53recoverycontrolconfig.model
import zio.aws.route53recoverycontrolconfig.model.primitives.__string
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters.*
final case class DescribeClusterRequest(clusterArn: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.route53recoverycontrolconfig.model.DescribeClusterRequest = {
    import DescribeClusterRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.route53recoverycontrolconfig.model.DescribeClusterRequest
      .builder()
      .clusterArn(__string.unwrap(clusterArn): java.lang.String)
      .build()
  }
  def asReadOnly
      : zio.aws.route53recoverycontrolconfig.model.DescribeClusterRequest.ReadOnly =
    zio.aws.route53recoverycontrolconfig.model.DescribeClusterRequest
      .wrap(buildAwsValue())
}
object DescribeClusterRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.route53recoverycontrolconfig.model.DescribeClusterRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.route53recoverycontrolconfig.model.DescribeClusterRequest =
      zio.aws.route53recoverycontrolconfig.model
        .DescribeClusterRequest(clusterArn)
    def clusterArn: __string
    def getClusterArn: ZIO[Any, Nothing, __string] = ZIO.succeed(clusterArn)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.route53recoverycontrolconfig.model.DescribeClusterRequest
  ) extends zio.aws.route53recoverycontrolconfig.model.DescribeClusterRequest.ReadOnly {
    override val clusterArn: __string =
      zio.aws.route53recoverycontrolconfig.model.primitives
        .__string(impl.clusterArn())
  }
  def wrap(
      impl: software.amazon.awssdk.services.route53recoverycontrolconfig.model.DescribeClusterRequest
  ): zio.aws.route53recoverycontrolconfig.model.DescribeClusterRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-route53recoverycontrolconfig_3-5.17.295.1-sources.jar: zio/aws/route53recoverycontrolconfig/model/DescribeClusterRequest.scala <==
package zio.aws.route53recoverycontrolconfig.model
import zio.aws.route53recoverycontrolconfig.model.primitives.__string
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters.*
final case class DescribeClusterRequest(clusterArn: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.route53recoverycontrolconfig.model.DescribeClusterRequest = {
    import DescribeClusterRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.route53recoverycontrolconfig.model.DescribeClusterRequest
      .builder()
      .clusterArn(clusterArn: java.lang.String)
      .build()
  }
  def asReadOnly
      : zio.aws.route53recoverycontrolconfig.model.DescribeClusterRequest.ReadOnly =
    zio.aws.route53recoverycontrolconfig.model.DescribeClusterRequest
      .wrap(buildAwsValue())
}
object DescribeClusterRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.route53recoverycontrolconfig.model.DescribeClusterRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.route53recoverycontrolconfig.model.DescribeClusterRequest =
      zio.aws.route53recoverycontrolconfig.model
        .DescribeClusterRequest(clusterArn)
    def clusterArn: __string
    def getClusterArn: ZIO[Any, Nothing, __string] = ZIO.succeed(clusterArn)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.route53recoverycontrolconfig.model.DescribeClusterRequest
  ) extends zio.aws.route53recoverycontrolconfig.model.DescribeClusterRequest.ReadOnly {
    override val clusterArn: __string = impl.clusterArn(): __string
  }
  def wrap(
      impl: software.amazon.awssdk.services.route53recoverycontrolconfig.model.DescribeClusterRequest
  ): zio.aws.route53recoverycontrolconfig.model.DescribeClusterRequest.ReadOnly =
    new Wrapper(impl)
}
